@@ -8,7 +8,7 @@ https://www.aug.ipp.mpg.de/~git/pyaug/sfread.html
 
 """
 __author__  = 'Giovanni Tardini (Tel. 1898)'
-__version__ = '0.2.4'
+__version__ = '0.2.5'
 __date__    = '07.10.2021'
 
 import sys
@@ -17,8 +17,12 @@ from .sfread import *
 from .sf2equ import *
 from .libddc import ddcshotnr, previousshot
 from .mapeq import *
-from .ww import *
-from .sfh import *
+try:
+    from .ww import *
+    from .sfh import *
+except:
+    print('ww and sfh not loaded, SFREAD and EQU available')
+    pass
 
 # Backward compatibility.
 
